@@ -8,13 +8,15 @@ package App::MultiSsh;
 
 use strict;
 use warnings;
+use feature qw/:5.10/;
 use Carp;
 use POSIX qw/ceil/;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use base qw/Exporter/;
+use Path::Tiny;
 
-our $VERSION     = '0.13';
+our $VERSION     = '0.14';
 our @EXPORT_OK   = qw/hosts_from_map is_host multi_run shell_quote tmux/;
 our %EXPORT_TAGS = ();
 
@@ -172,6 +174,46 @@ sub layout {
     return $out;
 }
 
+sub config {
+    state $config;
+    return $config if $config;
+
+    my $config_file = path($ENV{HOME}, '.mssh');
+    if (!-f $config_file) {
+        $config = {};
+
+        # create a default config file
+        $config_file->spew("---\ngroups:\n");
+
+        return $config;
+    }
+
+    require YAML;
+    $config = YAML::LoadFile($config_file);
+
+    return $config;
+}
+
+sub get_groups {
+    my ($groups) = @_;
+    my $config = config();
+    my @hosts;
+
+    for my $group (@$groups) {
+        if ($config->{groups} && $config->{groups}{$group}) {
+            push @hosts,
+                ref $config->{groups}{$group}
+                ? @{ $config->{groups}{$group} }
+                : $config->{groups}{$group};
+        }
+        else {
+            warn "No host group '$group' defined in the config!\n";
+        }
+    }
+
+    return @hosts;
+}
+
 1;
 
 __END__
@@ -182,7 +224,7 @@ App::MultiSsh - Multi host ssh executer
 
 =head1 VERSION
 
-This documentation refers to App::MultiSsh version 0.13
+This documentation refers to App::MultiSsh version 0.14
 
 =head1 SYNOPSIS
 
@@ -203,6 +245,11 @@ This documentation refers to App::MultiSsh version 0.13
 
 Splits C<$host> into all hosts that it represents.
 
+eg
+
+  host0[012] -> host00, host01, host02
+  host0[0-2] -> host00, host01, host02
+
 =item C<is_host ($host)>
 
 Gets the full name of C<$host>
@@ -223,6 +270,14 @@ Generate a tmux session with all commands run in separate windows
 
 Generate a desired tmux layout
 
+=item C<config ()>
+
+Read the ~/.mssh config file and return it's data
+
+=item C<get_groups (@groups)>
+
+Return all hosts represented in C<@groups>
+
 =back
 
 =head1 DIAGNOSTICS
